summaryrefslogtreecommitdiff
path: root/mcon/pl/configure.pl
diff options
context:
space:
mode:
Diffstat (limited to 'mcon/pl/configure.pl')
-rw-r--r--mcon/pl/configure.pl10
1 files changed, 6 insertions, 4 deletions
diff --git a/mcon/pl/configure.pl b/mcon/pl/configure.pl
index a6b55ef..a5aed29 100644
--- a/mcon/pl/configure.pl
+++ b/mcon/pl/configure.pl
@@ -1,12 +1,12 @@
-;# $Id: configure.pl,v 3.0.1.5 1995/01/30 14:47:15 ram Exp $
+;# $Id$
;#
-;# Copyright (c) 1991-1993, Raphael Manfredi
+;# Copyright (c) 1991-1997, 2004-2006, Raphael Manfredi
;#
;# You may redistribute only under the terms of the Artistic Licence,
;# as specified in the README file that comes with the distribution.
;# You may reuse parts of this distribution only within the terms of
;# that same Artistic Licence; a copy of which may be found at the root
-;# of the source tree for dist 3.0.
+;# of the source tree for dist 4.0.
;#
;# $Log: configure.pl,v $
;# Revision 3.0.1.5 1995/01/30 14:47:15 ram
@@ -110,7 +110,9 @@ sub process_command {
s/<PACKAGENAME>/$package/g;
s/<MAINTLOC>/$maintloc/g;
s/<VERSION>/$version/g; # This is metaconfig's version
- s/<PATCHLEVEL>/$patchlevel/g; # And patchlevel information
+ s/<REVISION>/$revision/g; # And revision information
+ warn "\"$file\": usage of <PATCHLEVEL> is deprecated\n"
+ if s/<PATCHLEVEL>/$patchlevel/g;
s/<DATE>/$date/g;
s/<BASEREV>/$baserev/g;
s/<\$(\w+)>/eval("\$$1")/ge; # <$var> -> $var substitution